@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -19,28 +19,40 @@
 
 """Battery plugin."""
 
-# Import Glances libs
-from glances.core.glances_logging import logger
+import psutil
+
+from glances.logger import logger
 from glances.plugins.glances_plugin import GlancesPlugin
 
 # Batinfo library (optional; Linux-only)
+batinfo_tag = True
 try:
     import batinfo
 except ImportError:
-    logger.debug("Batinfo library not found. Glances cannot grab battery info.")
-    pass
+    logger.debug("batinfo library not found. Fallback to psutil.")
+    batinfo_tag = False
+
+# Availability:
+# Linux, Windows, FreeBSD (psutil>=5.1.0)
+# macOS (psutil>=5.4.2)
+psutil_tag = True
+try:
+    psutil.sensors_battery()
+except Exception as e:
+    logger.error("Cannot grab battery status {}.".format(e))
+    psutil_tag = False
 
 
 class Plugin(GlancesPlugin):
-
-    """Glances' battery capacity plugin.
+    """Glances battery capacity plugin.
 
     stats is a list
     """
 
     def __init__(self, args=None):
         """Init the plugin."""
-        GlancesPlugin.__init__(self, args=args)
+        super(Plugin, self).__init__(args=args,
+                                     stats_init_value=[])
 
         # Init the sensor class
         self.glancesgrabbat = GlancesGrabBat()
@@ -49,62 +61,72 @@ class Plugin(GlancesPlugin):
         # The HDD temp is displayed within the sensors plugin
         self.display_curse = False
 
-        # Init stats
-        self.reset()
-
-    def reset(self):
-        """Reset/init the stats."""
-        self.stats = []
-
+    @GlancesPlugin._check_decorator
     @GlancesPlugin._log_result_decorator
     def update(self):
         """Update battery capacity stats using the input method."""
-        # Reset stats
-        self.reset()
+        # Init new stats
+        stats = self.get_init_value()
 
-        if self.get_input() == 'local':
+        if self.input_method == 'local':
             # Update stats
             self.glancesgrabbat.update()
-            self.stats = self.glancesgrabbat.get()
+            stats = self.glancesgrabbat.get()
 
-        elif self.get_input() == 'snmp':
+        elif self.input_method == 'snmp':
             # Update stats using SNMP
             # Not avalaible
             pass
 
+        # Update the stats
+        self.stats = stats
+
         return self.stats
 
 
 class GlancesGrabBat(object):
-
     """Get batteries stats using the batinfo library."""
 
     def __init__(self):
         """Init batteries stats."""
-        try:
+        self.bat_list = []
+
+        if batinfo_tag:
             self.bat = batinfo.batteries()
-            self.initok = True
-            self.bat_list = []
-            self.update()
-        except Exception as e:
-            self.initok = False
-            logger.debug("Cannot init GlancesGrabBat class (%s)" % e)
+        elif psutil_tag:
+            self.bat = psutil
+        else:
+            self.bat = None
 
     def update(self):
         """Update the stats."""
-        if self.initok:
+        if batinfo_tag:
+            # Use the batinfo lib to grab the stats
+            # Compatible with multiple batteries
             self.bat.update()
-            self.bat_list = [{'label': _("Battery (%)"), 'value': self.getcapacitypercent()}]
+            self.bat_list = [{
+                'label': 'Battery',
+                'value': self.battery_percent,
+                'unit': '%'}]
+        elif psutil_tag and hasattr(self.bat.sensors_battery(), 'percent'):
+            # Use psutil to grab the stats
+            # Give directly the battery percent
+            self.bat_list = [{
+                'label': 'Battery',
+                'value': int(self.bat.sensors_battery().percent),
+                'unit': '%'}]
         else:
+            # No stats...
             self.bat_list = []
 
     def get(self):
         """Get the stats."""
         return self.bat_list
 
-    def getcapacitypercent(self):
+    @property
+    def battery_percent(self):
         """Get batteries capacity percent."""
-        if not self.initok or not self.bat.stat:
+        if not batinfo_tag or not self.bat.stat:
             return []
 
         # Init the bsum (sum of percent)
@@ -112,7 +134,7 @@ class GlancesGrabBat(object):
         bsum = 0
         for b in self.bat.stat:
             try:
-                bsum = bsum + int(b.capacity)
+                bsum += int(b.capacity)
             except ValueError:
                 return []
 
