@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -23,12 +23,11 @@ Help plugin.
 Just a stupid plugin to display the help screen.
 """
 
-from glances import __appname__, __version__, psutil_version
+from glances import __version__, psutil_version
 from glances.plugins.glances_plugin import GlancesPlugin
 
 
 class Plugin(GlancesPlugin):
-
     """Glances help plugin."""
 
     def __init__(self, args=None, config=None):
@@ -45,16 +44,21 @@ class Plugin(GlancesPlugin):
         self.view_data = {}
         self.generate_view_data()
 
+    def reset(self):
+        """No stats. It is just a plugin to display the help."""
+        pass
+
     def update(self):
         """No stats. It is just a plugin to display the help."""
         pass
 
     def generate_view_data(self):
-        self.view_data['version'] = '{0} {1}'.format(__appname__.title(), __version__)
-        self.view_data['psutil_version'] = ' with PSutil {0}'.format(psutil_version)
+        """Generate the views."""
+        self.view_data['version'] = '{} {}'.format('Glances', __version__)
+        self.view_data['psutil_version'] = ' with psutil {}'.format(psutil_version)
 
         try:
-            self.view_data['configuration_file'] = 'Configuration file: {0}'.format(self.config.loaded_config_file)
+            self.view_data['configuration_file'] = 'Configuration file: {}'.format(self.config.loaded_config_file)
         except AttributeError:
             pass
 
@@ -94,12 +98,15 @@ class Plugin(GlancesPlugin):
         self.view_data['show_hide_ip'] = msg_col2.format('I', 'Show/hide IP module')
         self.view_data['diskio_iops'] = msg_col2.format('B', 'Count/rate for Disk I/O')
         self.view_data['show_hide_top_menu'] = msg_col2.format('5', 'Show/hide top menu (QL, CPU, MEM, SWAP and LOAD)')
+        self.view_data['enable_disable_gpu'] = msg_col.format('G', 'Enable/disable gpu plugin')
+        self.view_data['enable_disable_mean_gpu'] = msg_col2.format('6', 'Enable/disable mean gpu')
         self.view_data['edit_pattern_filter'] = 'ENTER: Edit the process filter pattern'
 
     def get_view_data(self, args=None):
+        """Return the view."""
         return self.view_data
 
-    def msg_curse(self, args=None):
+    def msg_curse(self, args=None, max_width=None):
         """Return the list to display in the curse interface."""
         # Init the return message
         ret = []
@@ -167,6 +174,9 @@ class Plugin(GlancesPlugin):
         ret.append(self.curse_add_line(self.view_data['enable_disable_short_processname']))
         ret.append(self.curse_add_line(self.view_data['show_hide_irq']))
         ret.append(self.curse_new_line())
+        ret.append(self.curse_add_line(self.view_data['enable_disable_gpu']))
+        ret.append(self.curse_add_line(self.view_data['enable_disable_mean_gpu']))
+        ret.append(self.curse_new_line())
         ret.append(self.curse_add_line(self.view_data['enable_disable_irix']))
         ret.append(self.curse_add_line(self.view_data['quit']))
         ret.append(self.curse_new_line())
