@@ -3,7 +3,7 @@
 #
 # Glances - An eye on your system
 #
-# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -32,7 +32,8 @@ from glances.compat import text_type
 import requests
 
 SERVER_PORT = 61234
-URL = "http://localhost:%s/api/2" % SERVER_PORT
+API_VERSION = 3
+URL = "http://localhost:{}/api/{}".format(SERVER_PORT, API_VERSION)
 pid = None
 
 # Unitest class
@@ -47,6 +48,17 @@ class TestGlances(unittest.TestCase):
         """The function is called *every time* before test_*."""
         print('\n' + '=' * 78)
 
+    def http_get(self, url, deflate=False):
+        """Make the request"""
+        if deflate:
+            ret = requests.get(url,
+                               stream=True,
+                               headers={'Accept-encoding': 'deflate'})
+        else:
+            ret = requests.get(url,
+                               headers={'Accept-encoding': 'identity'})
+        return ret
+
     def test_000_start_server(self):
         """Start the Glances Web Server."""
         global pid
@@ -66,16 +78,26 @@ class TestGlances(unittest.TestCase):
         method = "all"
         print('INFO: [TEST_001] Get all stats')
         print("HTTP RESTful request: %s/%s" % (URL, method))
-        req = requests.get("%s/%s" % (URL, method))
+        req = self.http_get("%s/%s" % (URL, method))
 
         self.assertTrue(req.ok)
 
+    def test_001a_all_deflate(self):
+        """All."""
+        method = "all"
+        print('INFO: [TEST_001a] Get all stats (with Deflate compression)')
+        print("HTTP RESTful request: %s/%s" % (URL, method))
+        req = self.http_get("%s/%s" % (URL, method), deflate=True)
+
+        self.assertTrue(req.ok)
+        self.assertTrue(req.headers['Content-Encoding'] == 'deflate')
+
     def test_002_pluginslist(self):
         """Plugins list."""
         method = "pluginslist"
         print('INFO: [TEST_002] Plugins list')
         print("HTTP RESTful request: %s/%s" % (URL, method))
-        req = requests.get("%s/%s" % (URL, method))
+        req = self.http_get("%s/%s" % (URL, method))
 
         self.assertTrue(req.ok)
         self.assertIsInstance(req.json(), list)
@@ -85,11 +107,11 @@ class TestGlances(unittest.TestCase):
         """Plugins."""
         method = "pluginslist"
         print('INFO: [TEST_003] Plugins')
-        plist = requests.get("%s/%s" % (URL, method))
+        plist = self.http_get("%s/%s" % (URL, method))
 
         for p in plist.json():
             print("HTTP RESTful request: %s/%s" % (URL, p))
-            req = requests.get("%s/%s" % (URL, p))
+            req = self.http_get("%s/%s" % (URL, p))
             self.assertTrue(req.ok)
             if p in ('uptime', 'now'):
                 self.assertIsInstance(req.json(), text_type)
@@ -106,11 +128,11 @@ class TestGlances(unittest.TestCase):
         """Items."""
         method = "cpu"
         print('INFO: [TEST_004] Items for the CPU method')
-        ilist = requests.get("%s/%s" % (URL, method))
+        ilist = self.http_get("%s/%s" % (URL, method))
 
         for i in ilist.json():
             print("HTTP RESTful request: %s/%s/%s" % (URL, method, i))
-            req = requests.get("%s/%s/%s" % (URL, method, i))
+            req = self.http_get("%s/%s/%s" % (URL, method, i))
             self.assertTrue(req.ok)
             self.assertIsInstance(req.json(), dict)
             print(req.json()[i])
@@ -121,7 +143,7 @@ class TestGlances(unittest.TestCase):
         method = "processlist"
         print('INFO: [TEST_005] Item=Value for the PROCESSLIST method')
         print("%s/%s/pid/0" % (URL, method))
-        req = requests.get("%s/%s/pid/0" % (URL, method))
+        req = self.http_get("%s/%s/pid/0" % (URL, method))
 
         self.assertTrue(req.ok)
         self.assertIsInstance(req.json(), dict)
@@ -131,7 +153,7 @@ class TestGlances(unittest.TestCase):
         method = "all/limits"
         print('INFO: [TEST_006] Get all limits')
         print("HTTP RESTful request: %s/%s" % (URL, method))
-        req = requests.get("%s/%s" % (URL, method))
+        req = self.http_get("%s/%s" % (URL, method))
 
         self.assertTrue(req.ok)
         self.assertIsInstance(req.json(), dict)
@@ -141,7 +163,7 @@ class TestGlances(unittest.TestCase):
         method = "all/views"
         print('INFO: [TEST_007] Get all views')
         print("HTTP RESTful request: %s/%s" % (URL, method))
-        req = requests.get("%s/%s" % (URL, method))
+        req = self.http_get("%s/%s" % (URL, method))
 
         self.assertTrue(req.ok)
         self.assertIsInstance(req.json(), dict)
@@ -150,11 +172,11 @@ class TestGlances(unittest.TestCase):
         """Plugins limits."""
         method = "pluginslist"
         print('INFO: [TEST_008] Plugins limits')
-        plist = requests.get("%s/%s" % (URL, method))
+        plist = self.http_get("%s/%s" % (URL, method))
 
         for p in plist.json():
             print("HTTP RESTful request: %s/%s/limits" % (URL, p))
-            req = requests.get("%s/%s/limits" % (URL, p))
+            req = self.http_get("%s/%s/limits" % (URL, p))
             self.assertTrue(req.ok)
             self.assertIsInstance(req.json(), dict)
 
@@ -162,11 +184,11 @@ class TestGlances(unittest.TestCase):
         """Plugins views."""
         method = "pluginslist"
         print('INFO: [TEST_009] Plugins views')
-        plist = requests.get("%s/%s" % (URL, method))
+        plist = self.http_get("%s/%s" % (URL, method))
 
         for p in plist.json():
             print("HTTP RESTful request: %s/%s/views" % (URL, p))
-            req = requests.get("%s/%s/views" % (URL, p))
+            req = self.http_get("%s/%s/views" % (URL, p))
             self.assertTrue(req.ok)
             self.assertIsInstance(req.json(), dict)
 
@@ -175,22 +197,22 @@ class TestGlances(unittest.TestCase):
         method = "history"
         print('INFO: [TEST_010] History')
         print("HTTP RESTful request: %s/cpu/%s" % (URL, method))
-        req = requests.get("%s/cpu/%s" % (URL, method))
+        req = self.http_get("%s/cpu/%s" % (URL, method))
         self.assertIsInstance(req.json(), dict)
         self.assertIsInstance(req.json()['user'], list)
         self.assertTrue(len(req.json()['user']) > 0)
         print("HTTP RESTful request: %s/cpu/%s/3" % (URL, method))
-        req = requests.get("%s/cpu/%s/3" % (URL, method))
+        req = self.http_get("%s/cpu/%s/3" % (URL, method))
         self.assertIsInstance(req.json(), dict)
         self.assertIsInstance(req.json()['user'], list)
         self.assertTrue(len(req.json()['user']) > 1)
         print("HTTP RESTful request: %s/cpu/system/%s" % (URL, method))
-        req = requests.get("%s/cpu/system/%s" % (URL, method))
+        req = self.http_get("%s/cpu/system/%s" % (URL, method))
         self.assertIsInstance(req.json(), dict)
         self.assertIsInstance(req.json()['system'], list)
         self.assertTrue(len(req.json()['system']) > 0)
         print("HTTP RESTful request: %s/cpu/system/%s/3" % (URL, method))
-        req = requests.get("%s/cpu/system/%s/3" % (URL, method))
+        req = self.http_get("%s/cpu/system/%s/3" % (URL, method))
         self.assertIsInstance(req.json(), dict)
         self.assertIsInstance(req.json()['system'], list)
         self.assertTrue(len(req.json()['system']) > 1)
@@ -205,5 +227,6 @@ class TestGlances(unittest.TestCase):
 
         self.assertTrue(True)
 
+
 if __name__ == '__main__':
     unittest.main()
